"""Generated model names for anthropic-max provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 8
"""

from __future__ import annotations

from typing import Literal


# Fully-qualified model IDs (provider:model format)
AnthropicMaxModelId = Literal[
    "anthropic-max:claude-haiku-4-5",
    "anthropic-max:claude-haiku-4-5-20251001",
    "anthropic-max:claude-opus-4-1",
    "anthropic-max:claude-opus-4-1-20250805",
    "anthropic-max:claude-opus-4-5",
    "anthropic-max:claude-opus-4-5-20251101",
    "anthropic-max:claude-sonnet-4-5",
    "anthropic-max:claude-sonnet-4-5-20250929",
]

# Model names without provider prefix
AnthropicMaxModelName = Literal[
    "claude-haiku-4-5",
    "claude-haiku-4-5-20251001",
    "claude-opus-4-1",
    "claude-opus-4-1-20250805",
    "claude-opus-4-5",
    "claude-opus-4-5-20251101",
    "claude-sonnet-4-5",
    "claude-sonnet-4-5-20250929",
]

__all__ = ["AnthropicMaxModelId", "AnthropicMaxModelName"]
