"""Generated model names for claude-code provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 3
"""

from __future__ import annotations

from typing import Literal


# Fully-qualified model IDs (provider:model format)
ClaudeCodeModelId = Literal[
    "claude-code:haiku",
    "claude-code:opus",
    "claude-code:sonnet",
]

# Model names without provider prefix
ClaudeCodeModelName = Literal[
    "haiku",
    "opus",
    "sonnet",
]

__all__ = ["ClaudeCodeModelId", "ClaudeCodeModelName"]
