"""Generated model names for cerebras provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 3
"""

from __future__ import annotations

from typing import Literal


# Fully-qualified model IDs (provider:model format)
CerebrasModelId = Literal[
    "cerebras:gpt-oss-120b",
    "cerebras:qwen-3-235b-a22b-instruct-2507",
    "cerebras:zai-glm-4.7",
]

# Model names without provider prefix
CerebrasModelName = Literal[
    "gpt-oss-120b",
    "qwen-3-235b-a22b-instruct-2507",
    "zai-glm-4.7",
]

__all__ = ["CerebrasModelId", "CerebrasModelName"]
