"""Generated model names for copilot provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 20
"""

from __future__ import annotations

from typing import Literal


# Fully-qualified model IDs (provider:model format)
CopilotModelId = Literal[
    "copilot:claude-haiku-4.5",
    "copilot:claude-opus-4.5",
    "copilot:claude-sonnet-4",
    "copilot:claude-sonnet-4.5",
    "copilot:gemini-2.5-pro",
    "copilot:gemini-3-flash-preview",
    "copilot:gemini-3-pro-preview",
    "copilot:gpt-4.1",
    "copilot:gpt-4o",
    "copilot:gpt-5",
    "copilot:gpt-5-codex",
    "copilot:gpt-5-mini",
    "copilot:gpt-5.1",
    "copilot:gpt-5.1-codex",
    "copilot:gpt-5.1-codex-max",
    "copilot:gpt-5.1-codex-mini",
    "copilot:gpt-5.2",
    "copilot:gpt-5.2-codex",
    "copilot:grok-code-fast-1",
    "copilot:oswe-vscode-prime",
]

# Model names without provider prefix
CopilotModelName = Literal[
    "claude-haiku-4.5",
    "claude-opus-4.5",
    "claude-sonnet-4",
    "claude-sonnet-4.5",
    "gemini-2.5-pro",
    "gemini-3-flash-preview",
    "gemini-3-pro-preview",
    "gpt-4.1",
    "gpt-4o",
    "gpt-5",
    "gpt-5-codex",
    "gpt-5-mini",
    "gpt-5.1",
    "gpt-5.1-codex",
    "gpt-5.1-codex-max",
    "gpt-5.1-codex-mini",
    "gpt-5.2",
    "gpt-5.2-codex",
    "grok-code-fast-1",
    "oswe-vscode-prime",
]

__all__ = ["CopilotModelId", "CopilotModelName"]
