"""Generated model names for openai provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 15
"""

from __future__ import annotations

from typing import Literal


# Fully-qualified model IDs (provider:model format)
OpenaiModelId = Literal[
    "openai:gpt-5",
    "openai:gpt-5-chat-latest",
    "openai:gpt-5-codex",
    "openai:gpt-5-mini",
    "openai:gpt-5-nano",
    "openai:gpt-5-pro",
    "openai:gpt-5.1",
    "openai:gpt-5.1-chat-latest",
    "openai:gpt-5.1-codex",
    "openai:gpt-5.1-codex-max",
    "openai:gpt-5.1-codex-mini",
    "openai:gpt-5.2",
    "openai:gpt-5.2-chat-latest",
    "openai:gpt-5.2-codex",
    "openai:gpt-5.2-pro",
]

# Model names without provider prefix
OpenaiModelName = Literal[
    "gpt-5",
    "gpt-5-chat-latest",
    "gpt-5-codex",
    "gpt-5-mini",
    "gpt-5-nano",
    "gpt-5-pro",
    "gpt-5.1",
    "gpt-5.1-chat-latest",
    "gpt-5.1-codex",
    "gpt-5.1-codex-max",
    "gpt-5.1-codex-mini",
    "gpt-5.2",
    "gpt-5.2-chat-latest",
    "gpt-5.2-codex",
    "gpt-5.2-pro",
]

__all__ = ["OpenaiModelId", "OpenaiModelName"]
