"""Generated model names for zai provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 7
"""

from __future__ import annotations

from typing import Literal


# Fully-qualified model IDs (provider:model format)
ZaiModelId = Literal[
    "zai:glm-4.5",
    "zai:glm-4.5-air",
    "zai:glm-4.5-flash",
    "zai:glm-4.5v",
    "zai:glm-4.6",
    "zai:glm-4.6v",
    "zai:glm-4.7",
]

# Model names without provider prefix
ZaiModelName = Literal[
    "glm-4.5",
    "glm-4.5-air",
    "glm-4.5-flash",
    "glm-4.5v",
    "glm-4.6",
    "glm-4.6v",
    "glm-4.7",
]

__all__ = ["ZaiModelId", "ZaiModelName"]
